@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "just-mode" "0.1.8"
+(define-package "just-mode" "20251121.1826"
   "Justfile editing mode."
   '((emacs "26.1"))
   :url "https://github.com/leon-barrett/just-mode.el"
-  :commit "d7f52eab8fa3828106f80acb1e2176e5877b7191"
-  :revdesc "d7f52eab8fa3"
+  :commit "b6173c7bf4d8d28e0dbd80fa41b9c75626885b4e"
+  :revdesc "b6173c7bf4d8"
   :keywords '("files" "languages" "tools")
   :authors '(("Leon Barrett" . "(leon@barrettnexus.com)"))
   :maintainers '(("Leon Barrett" . "(leon@barrettnexus.com)")))
